@@ -20,6 +20,7 @@ from .Utils import loggers
 from .Message import message_center as mc
 from typing import Any
 from . import NetworkError
+import json
 
 LOGGER_NAME = "RPCServer"
 
@@ -57,10 +58,9 @@ class RPCServer(object):
 
         async def init_worker() -> Any:
             nonlocal ip, port
-            self.__server = await websockets.serve(self.__on_new_onnection,
-                                                   ip,
+            self.__server = await websockets.serve(self.__on_new_onnection, ip,
                                                    port,
-                                                   max_size=max_size * (2**20))
+                                                   max_size=max_size * (2 ** 20))
 
         self.__loop.run_until_complete(init_worker())
 
@@ -85,22 +85,29 @@ class RPCServer(object):
     async def __call_worker(self, websocket, rpc_id, method, **params) -> None:
         try:
             self.__sender_ws = websocket
-            rpc_result = await mc.call(websocket.remote_address, method,
-                                       **params)
+            rpc_result = await mc.call(method, **params)
             feedback = self.__pack_rpc(rpc_id, rpc_result)
         except Exception as e:
             feedback = self.__pack_rpc(rpc_id, e)
 
         address = "%s:%s" % (str(websocket.host), str(websocket.port))
-        remote_address = "%s:%s" % (str(
-            websocket.remote_address[0]), str(websocket.remote_address[1]))
+        remote_address = "%s:%s" % (
+            str(websocket.remote_address[0]), str(websocket.remote_address[1]))
 
-        loggers.get(LOGGER_NAME).debug(
-            "S(%s) >> C(%s): %s" %
-            (str(address), str(remote_address), str(feedback)))
+        # todo: 暂时使用, 不应该在这里解释数据
+        try:
+            json_data = json.loads(feedback)
+            if "params" in json_data and len(json_data["params"]) > 100:
+                json_data["params"] = "..."
+            loggers.get(LOGGER_NAME).debug(
+                "S(%s) >> C(%s): %s" % (str(address), str(remote_address), json.dumps(json_data)))
+        except Exception as e:
+            loggers.get(LOGGER_NAME).debug(
+                "S(%s) >> C(%s): %s" % (str(address), str(remote_address), str(feedback)))
         await websocket.send(feedback)
 
-    async def __on_new_onnection(self, websocket: WebSocketServerProtocol, _):
+    async def __on_new_onnection(self, websocket: WebSocketServerProtocol,
+                                 _):
         ip = websocket.remote_address[0]
         port = websocket.remote_address[1]
         address = "%s:%s" % (str(websocket.host), str(websocket.port))
@@ -111,13 +118,12 @@ class RPCServer(object):
             send_str = "You had been baned."
 
             loggers.get(LOGGER_NAME).debug(
-                "S(%s) >> C(%s): %s" %
-                (str(address), str(remote_address), str(send_str)))
+                "S(%s) >> C(%s): %s" % (str(address), str(remote_address), str(send_str)))
             await websocket.send(send_str)
             return
 
-        loggers.get(LOGGER_NAME).info("Client(%s:%s) connected." %
-                                      (str(ip), str(port)))
+        loggers.get(LOGGER_NAME).info(
+            "Client(%s:%s) connected." % (str(ip), str(port)))
         self.__ws_clients.add(websocket)
 
         if self.__on_connected:
@@ -128,9 +134,16 @@ class RPCServer(object):
         while True:
             try:
                 message = await websocket.recv()
-                loggers.get(LOGGER_NAME).debug(
-                    "S(%s) << C(%s): %s" %
-                    (str(address), str(remote_address), str(message)))
+                # todo: 暂时使用, 不应该在这里解释数据
+                try:
+                    json_data = json.loads(message)
+                    if "params" in json_data and len(json_data["params"]) > 100:
+                        json_data["params"] = "..."
+                    loggers.get(LOGGER_NAME).debug(
+                        "S(%s) << C(%s): %s" % (str(address), str(remote_address), json.dumps(json_data)))
+                except Exception as e:
+                    loggers.get(LOGGER_NAME).debug(
+                        "S(%s) << C(%s): %s" % (str(address), str(remote_address), str(message)))
             except Exception as e:
                 loggers.get(LOGGER_NAME).error(e, exc_info=True)
                 break
@@ -150,13 +163,12 @@ class RPCServer(object):
             except Exception as e:
                 loggers.get(LOGGER_NAME).error(e, exc_info=True)
                 loggers.get(LOGGER_NAME).debug(
-                    "S(%s) >> C(%s): %s" %
-                    (str(address), str(remote_address), str(e)))
+                    "S(%s) >> C(%s): %s" % (str(address), str(remote_address), str(e)))
                 await websocket.send(str(e))
                 continue
 
-        loggers.get(LOGGER_NAME).warning("%s:%s had disconnected!!!!!!!!" %
-                                         (str(ip), str(port)))
+        loggers.get(LOGGER_NAME).warning(
+            "%s:%s had disconnected!!!!!!!!" % (str(ip), str(port)))
         self.__ws_clients.remove(websocket)
 
         if self.__on_disconnected:
@@ -187,9 +199,7 @@ class RPCServer(object):
 
         return rpc_id, method, params, result, error
 
-    def __pack_rpc(self,
-                   rpc_id: int,
-                   rpc_playload: Any,
+    def __pack_rpc(self, rpc_id: int, rpc_playload: Any,
                    method: str = None) -> str:
         if rpc_id is None:
             data = {"jsonrpc": "2.0"}
@@ -206,10 +216,8 @@ class RPCServer(object):
                 if "code" in error_str:
                     rpc_playload = demjson.decode(error_str)
                 else:
-                    rpc_playload = {
-                        "code": -32000,
-                        "message": "%s" % error_str
-                    }
+                    rpc_playload = {"code": -32000,
+                                    "message": "%s" % error_str}
                 loggers.get(LOGGER_NAME).error(rpc_playload, exc_info=True)
                 data["error"] = rpc_playload
             else:
@@ -255,11 +263,10 @@ class RPCServer(object):
         tasks = []
         for websocket in self.__ws_clients:
             address = "%s:%s" % (str(websocket.host), str(websocket.port))
-            remote_address = "%s:%s" % (str(
-                websocket.remote_address[0]), str(websocket.remote_address[1]))
+            remote_address = "%s:%s" % (
+                str(websocket.remote_address[0]), str(websocket.remote_address[1]))
             loggers.get(LOGGER_NAME).debug(
-                "S(%s) >> C(%s): %s" %
-                (str(address), str(remote_address), str(feedback)))
+                "S(%s) >> C(%s): %s" % (str(address), str(remote_address), str(feedback)))
             tasks.append(websocket.send(rpc_packet))
         await asyncio.wait(tasks)
 
